@@ -1,10 +1,10 @@
 from __future__ import absolute_import, division, print_function
 
 from larray.core import *
-from larray.io import *
+from larray.inout import *
 from larray.util import *
 from larray.example import *
 from larray.extra import *
 from larray.viewer import *
 
-__version__ = "0.24"
+__version__ = "0.26"
