@@ -3,16 +3,17 @@ from __future__ import absolute_import, division, print_function
 
 import re
 import sys
+import warnings
 from itertools import product, chain
 
 import numpy as np
 import pandas as pd
 
-from larray.core.abc import ABCAxis, ABCAxisReference, ABCLArray
+from larray.core.abstractbases import ABCAxis, ABCAxisReference, ABCLArray
 from larray.util.oset import *
-from larray.util.misc import basestring, PY2, unique, find_closing_chr, _parse_bound, _seq_summary
+from larray.util.misc import basestring, PY2, unique, find_closing_chr, _parse_bound, _seq_summary, renamed_to
 
-__all__ = ['LGroup', 'LSet', 'PGroup', 'union']
+__all__ = ['Group', 'LGroup', 'LSet', 'IGroup', 'union']
 
 
 def _slice_to_str(key, repr_func=str):
@@ -169,8 +170,8 @@ def generalized_range(start, stop, step=1):
                 stop_pad = len(stop_part) if stop_part.startswith('0') else None
                 if start_pad is not None and stop_pad is not None and start_pad != stop_pad:
                     raise ValueError("Inconsistent zero padding for start and stop ({} vs {}) of the numerical part. "
-                                     "Must be either the same on both sides or no padding on either "
-                                     "side".format(start_pad, stop_pad))
+                                     "Must be either the same on both sides or no padding on either side"
+                                     .format(start_pad, stop_pad))
                 elif start_pad is None and stop_pad is None:
                     r = [str(num) for num in rng]
                 else:
@@ -226,6 +227,7 @@ def _range_str_to_range(s, stack_depth=1):
     >>> _range_str_to_range('a|+*@-b .. a|+*@-d')
     ['a|+*@-b', 'a|+*@-c', 'a|+*@-d']
     """
+    s = s.strip()
     m = _range_str_pattern.match(s)
 
     groups = m.groupdict()
@@ -241,8 +243,7 @@ def _range_str_to_range(s, stack_depth=1):
 
 def _range_to_slice(seq, length=None):
     """
-    Returns a slice if possible (including for sequences of 1 element)
-    otherwise returns the input sequence itself
+    Returns a slice if possible (including for sequences of 1 element) otherwise returns the input sequence itself
 
     Parameters
     ----------
@@ -250,9 +251,8 @@ def _range_to_slice(seq, length=None):
         List, tuple or ndarray of integers representing the range.
         It should be something like [start, start+step, start+2*step, ...]
     length : int, optional
-        length of sequence of positions.
-        This is only useful when you must be able to transform decreasing
-        sequences which can stop at 0.
+        length of sequence of positions. This is only useful when you must be able to transform decreasing sequences
+        which can stop at 0.
 
     Returns
     -------
@@ -344,14 +344,11 @@ def _to_tick(v):
     any scalar
         scalar representing the tick
     """
-    # the fact that an "aggregated tick" is passed as a LGroup or as a
-    # string should be as irrelevant as possible. The thing is that we cannot
-    # (currently) use the more elegant _to_tick(e.key) that means the
-    # LGroup is not available in Axis.__init__ after to_ticks, and we
-    # need it to update the mapping if it was named. Effectively,
-    # this creates two entries in the mapping for a single tick. Besides,
-    # I like having the LGroup as the tick, as it provides extra info as
-    # to where it comes from.
+    # the fact that an "aggregated tick" is passed as a LGroup or as a string should be as irrelevant as possible.
+    # The thing is that we cannot (currently) use the more elegant _to_tick(e.key) that means the LGroup is not
+    # available in Axis.__init__ after to_ticks, and we need it to update the mapping if it was named. Effectively,
+    # this creates two entries in the mapping for a single tick. Besides, I like having the LGroup as the tick, as it
+    # provides extra info as to where it comes from.
     if np.isscalar(v):
         return v
     elif isinstance(v, Group):
@@ -368,11 +365,11 @@ def _to_tick(v):
         return str(v)
 
 
-def _to_ticks(s):
+def _to_ticks(s, parse_single_int=False):
     """
-    Makes a (list of) value(s) usable as the collection of labels for an
-    Axis (ie hashable). Strip strings, split them on ',' and translate
-    "range strings" to list of values **including the end point** !
+    Makes a (list of) value(s) usable as the collection of labels for an Axis (ie hashable).
+
+    Strip strings, split them on ',' and translate "range strings" to list of values **including the end point** !
 
     Parameters
     ----------
@@ -395,10 +392,11 @@ def _to_ticks(s):
     ['A', 'C', 'D', 'E', 'F', 'G', 'Z']
     >>> _to_ticks('U')
     ['U']
-
     >>> list(_to_ticks('..3'))
     [0, 1, 2, 3]
     """
+    if isinstance(s, ABCAxis):
+        return s.labels
     if isinstance(s, Group):
         # a single LGroup used for all ticks of an Axis
         return _to_ticks(s.eval())
@@ -413,10 +411,10 @@ def _to_ticks(s):
     elif sys.version >= '3' and isinstance(s, range):
         return list(s)
     elif isinstance(s, basestring):
-        seq = _seq_str_to_seq(s)
+        seq = _seq_str_to_seq(s, parse_single_int=parse_single_int)
         if isinstance(seq, slice):
             raise ValueError("using : to define axes is deprecated, please use .. instead")
-        elif isinstance(seq, basestring):
+        elif isinstance(seq, (basestring, int)):
             return [seq]
         else:
             return seq
@@ -557,12 +555,11 @@ def _to_key(v, stack_depth=1, parse_single_int=False):
             axis_bracket_open = m.end(1) - 1
             # check that the string parentheses are correctly balanced
             _ = find_closing_chr(v, axis_bracket_open)
-            # strip closing bracket (it should be at the end because we took
-            # care of the name earlier)
+            # strip closing bracket (it should be at the end because we took care of the name earlier)
             assert key[-1] == ']'
             key = key[:-1]
         if name is not None or axis is not None:
-            cls = PGroup if positional else LGroup
+            cls = IGroup if positional else LGroup
             key = _to_key(key, stack_depth + 1, parse_single_int=positional)
             return cls(key, name=name, axis=axis)
         else:
@@ -570,13 +567,13 @@ def _to_key(v, stack_depth=1, parse_single_int=False):
     elif v is Ellipsis or np.isscalar(v) or isinstance(v, (Group, slice, list, np.ndarray, ABCLArray, OrderedSet)):
         return v
     else:
-        raise TypeError("%s has an invalid type (%s) for a key"
-                        % (v, type(v).__name__))
+        raise TypeError("%s has an invalid type (%s) for a key" % (v, type(v).__name__))
 
 
 def _to_keys(value, stack_depth=1):
     """
     Converts a (collection of) group(s) to a structure usable for indexing.
+
     'label' or ['l1', 'l2'] or [['l1', 'l2'], ['l3']]
 
     Parameters
@@ -633,6 +630,28 @@ def _to_keys(value, stack_depth=1):
         return _to_key(value, stack_depth + 1)
 
 
+# forbidden characters in sheet names
+_sheet_name_pattern = re.compile('[\\\/?*\[\]:]')
+
+
+def _translate_sheet_name(sheet_name):
+    if isinstance(sheet_name, Group):
+        sheet_name = _sheet_name_pattern.sub('_', str(_to_tick(sheet_name)))
+    if isinstance(sheet_name, basestring) and len(sheet_name) > 30:
+        raise ValueError("Sheet names cannot exceed 31 characters")
+    return sheet_name
+
+
+# forbidden characters for dataset names in HDF files
+_key_hdf_pattern = re.compile('[\\\/]')
+
+
+def _translate_key_hdf(key):
+    if isinstance(key, Group):
+        key = _key_hdf_pattern.sub('_', str(_to_tick(key)))
+    return key
+
+
 def union(*args):
     # TODO: add support for LGroup and lists
     """
@@ -641,8 +660,7 @@ def union(*args):
     Parameters
     ----------
     *args
-        (collection of) value(s) to be converted into label(s).
-        Repeated values are taken only once.
+        (collection of) value(s) to be converted into label(s). Repeated values are taken only once.
 
     Returns
     -------
@@ -659,9 +677,9 @@ def union(*args):
         return []
 
 
-class PGroupMaker(object):
+class IGroupMaker(object):
     """
-    Generates a new instance of PGroup for a given axis and key.
+    Generates a new instance of IGroup for a given axis and key.
 
     Attributes
     ----------
@@ -677,13 +695,11 @@ class PGroupMaker(object):
         self.axis = axis
 
     def __getitem__(self, key):
-        return PGroup(key, None, self.axis)
+        return IGroup(key, None, self.axis)
 
 
-# We need a separate class for LGroup and cannot simply create a
-# new Axis with a subset of values/ticks/labels: the subset of
-# ticks/labels of the LGroup need to correspond to its *Axis*
-# indices
+# We need a separate class for LGroup and cannot simply create a new Axis with a subset of values/ticks/labels:
+# the subset of ticks/labels of the LGroup need to correspond to its *Axis* indices
 class Group(object):
     """Abstract Group.
     """
@@ -696,25 +712,20 @@ class Group(object):
             key = key.to_label()
         self.key = remove_nested_groups(key)
 
-        # we do NOT assign a name automatically when missing because that
-        # makes it impossible to know whether a name was explicitly given or
-        # not
-        self.name = name
+        # we do NOT assign a name automatically when missing because that makes it impossible to know whether a name
+        # was explicitly given or not
+        self.name = str(_to_tick(name)) if name is not None else name
         assert axis is None or isinstance(axis, (basestring, int, ABCAxis)), \
             "invalid axis '%s' (%s)" % (axis, type(axis).__name__)
 
-        # we could check the key is valid but this can be slow and could be
-        # useless
-        # TODO: for performance reasons, we should cache the result. This will
-        # need to be invalidated correctly
+        # we could check the key is valid but this can be slow and could be useless
+        # TODO: for performance reasons, we should cache the result. This will need to be invalidated correctly
         # axis.translate(key)
 
-        # we store the Axis object and not its name like we did previously
-        # so that groups on anonymous axes are more meaningful and that we
-        # can iterate on a slice of an axis (an LGroup). The reason to store
-        # the name instead of the object was to make sure that a Group from an
-        # axis (or without axis) could be used on another axis with the same
-        # name. See test_array.py:test_...
+        # we store the Axis object and not its name like we did previously so that groups on anonymous axes are more
+        # meaningful and that we can iterate on a slice of an axis (an LGroup). The reason to store the name instead of
+        # the object was to make sure that a Group from an axis (or without axis) could be used on another axis with
+        # the same name. See test_array.py:test_...
         self.axis = axis
 
     def __repr__(self):
@@ -730,7 +741,7 @@ class Group(object):
 
         axis_name = self.axis.name if isinstance(self.axis, ABCAxis) else self.axis
         if axis_name is not None:
-            axis_name = 'x.{}'.format(axis_name) if isinstance(self.axis, ABCAxisReference) else axis_name
+            axis_name = 'X.{}'.format(axis_name) if isinstance(self.axis, ABCAxisReference) else axis_name
             s = self.format_string.format(axis=axis_name, key=key_repr)
         else:
             if self.axis is not None:
@@ -821,13 +832,13 @@ class Group(object):
         # XXX: we probably want to_label instead of .eval (so that we do not expand slices)
         value = self.eval()
         # for some reason this breaks having LGroup ticks/labels on an axis
-        if hasattr(value, '__len__'):
         # if isinstance(value, (tuple, list, LArray, np.ndarray, str)):
+        if hasattr(value, '__len__'):
             return len(value)
         elif isinstance(value, slice):
             start, stop, key_step = value.start, value.stop, value.step
-            # not using stop - start because that does not work for string
-            # bounds (and it is different for LGroup & PGroup)
+            # not using stop - start because that does not work for string bounds
+            # (and it is different for LGroup & IGroup)
             start_pos = self.translate(start)
             stop_pos = self.translate(stop)
             return stop_pos - start_pos
@@ -835,7 +846,7 @@ class Group(object):
             raise TypeError('len() of unsized object ({})'.format(value))
 
     def __iter__(self):
-        # XXX: use translate/PGroup instead, so that it works even in the presence of duplicate labels
+        # XXX: use translate/IGroup instead, so that it works even in the presence of duplicate labels
         #      possibly, only if axis is set?
         return iter([LGroup(v, axis=self.axis) for v in self.eval()])
 
@@ -880,8 +891,7 @@ class Group(object):
 
         Notes
         -----
-        step can be smaller than length, in which case, this will produce
-        overlapping groups.
+        step can be smaller than length, in which case, this will produce overlapping groups.
 
         Returns
         -------
@@ -889,7 +899,7 @@ class Group(object):
 
         Examples
         --------
-        >>> from larray import Axis, x
+        >>> from larray import Axis, X
         >>> age = Axis(range(10), 'age')
         >>> age[[1, 2, 3, 4, 5]].by(2)
         (age[1, 2], age[3, 4], age[5])
@@ -899,27 +909,26 @@ class Group(object):
         (age.i[1:3], age.i[5:6])
         >>> age[1:5].by(3, 2)
         (age.i[1:4], age.i[3:6], age.i[5:6])
-        >>> x.age[[0, 1, 2, 3, 4]].by(2)
-        (x.age[0, 1], x.age[2, 3], x.age[4])
+        >>> X.age[[0, 1, 2, 3, 4]].by(2)
+        (X.age[0, 1], X.age[2, 3], X.age[4])
         """
         if step is None:
             step = length
         return tuple(self[start:start + length]
                      for start in range(0, len(self), step))
 
-    # TODO: __getitem__ should work by label and .i[] should work by
-    # position. I guess it would be more consistent this way even if the
-    # usefulness of subsetting a group with labels is dubious (but
-    # it is sometimes practical to treat the group as if it was an axis).
+    # TODO: __getitem__ should work by label and .i[] should work by position. I guess it would be more consistent this
+    # way even if the usefulness of subsetting a group with labels is dubious (but it is sometimes practical to treat
+    # the group as if it was an axis).
     # >>> vla = geo['...']
     # >>> # first 10 regions of flanders (this could have some use)
-    # >>> vla.i[:10]  # => PGroup on geo
+    # >>> vla.i[:10]  # => IGroup on geo
     # >>> vla["antwerp", "gent"]  # => LGroup on geo
 
     # LGroup[] => LGroup
-    # PGroup[] => LGroup
-    # PGroup.i[] => PGroup
-    # LGroup.i[] => PGroup
+    # IGroup[] => LGroup
+    # IGroup.i[] => IGroup
+    # LGroup.i[] => IGroup
     def __getitem__(self, key):
         """
 
@@ -938,8 +947,7 @@ class Group(object):
         if isinstance(orig_key, (tuple, list)):
             return cls(orig_key[key], None, self.axis)
         elif isinstance(orig_key, slice):
-            orig_start, orig_stop, orig_step = \
-                orig_key.start, orig_key.stop, orig_key.step
+            orig_start, orig_stop, orig_step = orig_key.start, orig_key.stop, orig_key.step
             if orig_step is None:
                 orig_step = 1
 
@@ -951,27 +959,24 @@ class Group(object):
 
                 orig_stop_pos = self.translate(orig_stop, stop=True) if orig_stop is not None else len(self)
                 new_start = orig_start_pos + key_start * orig_step
-                new_stop = min(orig_start_pos + key_stop * orig_step,
-                               orig_stop_pos)
+                new_stop = min(orig_start_pos + key_stop * orig_step, orig_stop_pos)
                 new_step = orig_step * key_step
                 if new_step == 1:
                     new_step = None
-                return PGroup(slice(new_start, new_stop, new_step), None,
-                              self.axis)
+                return IGroup(slice(new_start, new_stop, new_step), None, self.axis)
             elif isinstance(key, int):
-                return PGroup(orig_start_pos + key * orig_step, None, self.axis)
+                return IGroup(orig_start_pos + key * orig_step, None, self.axis)
             elif isinstance(key, (tuple, list)):
-                return PGroup([orig_start_pos + k * orig_step for k in key],
-                              None, self.axis)
+                return IGroup([orig_start_pos + k * orig_step for k in key], None, self.axis)
         elif isinstance(orig_key, ABCLArray):
+            # XXX: why .i ?
             return cls(orig_key.i[key], None, self.axis)
         elif isinstance(orig_key, int):
             # give the opportunity to subset the label/key itself (for example for string keys)
             value = self.eval()
             return value[key]
         else:
-            raise TypeError("cannot take a subset of {} because it has a "
-                            "'{}' key".format(self.key, type(self.key)))
+            raise TypeError("cannot take a subset of {} because it has a '{}' key".format(self.key, type(self.key)))
 
     def _ipython_key_completions_(self):
         return list(self.eval())
@@ -980,16 +985,20 @@ class Group(object):
     def _binop(opname):
         op_fullname = '__%s__' % opname
 
-        # TODO: implement this in a delayed fashion for reference axes
+        # TODO: implement this in a delayed fashion for axes references
         if PY2:
             # workaround the fact slice objects do not have any __binop__ methods defined on Python2 (even though
             # the actual operations work on them).
             def opmethod(self, other):
                 self_value = self.eval()
                 other_value = other.eval() if isinstance(other, Group) else other
+                # this can only happen when self.axis is not an Axis instance
                 if isinstance(self_value, slice):
                     if not isinstance(other_value, slice):
+                        # FIXME: we should raise a TypeError instead for all ops except == and !=
+                        # FIXME: we should return True for !=
                         return False
+                    # FIXME: we should raise a TypeError instead of doing this for all ops except comparison ops
                     self_value = (self_value.start, self_value.stop, self_value.step)
                     other_value = (other_value.start, other_value.stop, other_value.step)
                 return getattr(self_value, op_fullname)(other_value)
@@ -1131,15 +1140,140 @@ class Group(object):
             item = item.eval()
         return item in self.eval()
 
+    def startingwith(self, prefix):
+        """
+        Returns a group with the labels starting with the specified string.
+
+        Parameters
+        ----------
+        prefix : str or Group
+            The prefix to search for.
+
+        Returns
+        -------
+        LGroup
+            Group containing all the labels starting with the given string.
+
+        Examples
+        --------
+        >>> from larray import Axis
+        >>> people = Axis(['Bruce Wayne', 'Arthur Dent', 'Harvey Dent'], 'people')
+        >>> group = people.endingwith('Dent')
+        >>> group
+        people['Arthur Dent', 'Harvey Dent']
+        >>> group.startingwith('Art')
+        people['Arthur Dent']
+        """
+        if isinstance(prefix, Group):
+            prefix = prefix.eval()
+        return LGroup([v for v in self.eval() if v.startswith(prefix)], axis=self.axis)
+
+    def endingwith(self, suffix):
+        """
+        Returns a group with the labels ending with the specified string.
+
+        Parameters
+        ----------
+        suffix : str or Group
+            The suffix to search for.
+
+        Returns
+        -------
+        LGroup
+            Group containing all the labels ending with the given string.
+
+        Examples
+        --------
+        >>> from larray import Axis
+        >>> people = Axis(['Bruce Wayne', 'Bruce Willis', 'Arthur Dent'], 'people')
+        >>> group = people.startingwith('Bru')
+        >>> group
+        people['Bruce Wayne', 'Bruce Willis']
+        >>> people.endingwith('yne')
+        people['Bruce Wayne']
+        """
+        if isinstance(suffix, Group):
+            suffix = suffix.eval()
+        return LGroup([v for v in self.eval() if v.endswith(suffix)], axis=self.axis)
+
+    def matching(self, pattern):
+        """
+        Returns a group with all the labels matching the specified pattern (regular expression).
+
+        Parameters
+        ----------
+        pattern : str or Group
+            Regular expression (regex).
+
+        Returns
+        -------
+        LGroup
+            Group containing all the labels matching the pattern.
+
+        Notes
+        -----
+        See `Regular Expression <https://docs.python.org/3/library/re.html>`_
+        for more details about how to build a pattern.
+
+        Examples
+        --------
+        >>> from larray import Axis
+        >>> people = Axis(['Bruce Wayne', 'Bruce Willis', 'Arthur Dent'], 'people')
+
+        All labels containing "B" and "e" with exactly 3 characters in between are given by
+
+        >>> group = people.matching('B...e')
+        >>> group
+        people['Bruce Wayne', 'Bruce Willis']
+
+        Within that group, all labels containing any characters then W then any characters then s are given by
+        >>> group.matching('.*W.*s')
+        people['Bruce Willis']
+        """
+        if isinstance(pattern, Group):
+            pattern = pattern.eval()
+        rx = re.compile(pattern)
+        return LGroup([v for v in self.eval() if rx.match(v)], axis=self.axis)
+
+    def containing(self, substring):
+        """
+        Returns a group with all the labels containing the specified substring.
+
+        Parameters
+        ----------
+        substring : str or Group
+            The substring to search for.
+
+        Returns
+        -------
+        LGroup
+            Group containing all the labels containing the substring.
+
+        Examples
+        --------
+        >>> from larray import Axis
+        >>> people = Axis(['Bruce Wayne', 'Bruce Willis', 'Arthur Dent'], 'people')
+        >>> group = people.startingwith('Bru')
+        >>> group
+        people['Bruce Wayne', 'Bruce Willis']
+        >>> group.containing('Will')
+        people['Bruce Willis']
+        """
+        if isinstance(substring, Group):
+            substring = substring.eval()
+        return LGroup([v for v in self.eval() if substring in v], axis=self.axis)
+
     # this makes range(LGroup(int)) possible
     def __index__(self):
         return self.eval().__index__()
 
     def __int__(self):
-        return self.eval().__int__()
+        # 'str' objects have no '__int__' attribute, so this is better than calling __int__ explicitly
+        return int(self.eval())
 
     def __float__(self):
-        return self.eval().__float__()
+        # 'str' objects have no '__float__' attribute, so this is better than calling __float__ explicitly
+        return float(self.eval())
 
     def __array__(self, dtype=None):
         return np.asarray(self.eval(), dtype=dtype)
@@ -1156,14 +1290,12 @@ class Group(object):
             return getattr(self.eval(), key)
 
     def __hash__(self):
-        # to_tick & to_key are partially opposite operations but this
-        # standardize on a single notation so that they can all target each
-        # other. eg, this removes spaces in "list strings", instead of
-        # hashing them directly
-        # XXX: but we might want to include that normalization feature in
-        #      to_tick directly, instead of using to_key explicitly here
-        # XXX: we might want to make hash use the position along the axis instead of the labels so that if an
-        #      axis has ambiguous labels, they do not hash to the same thing.
+        # to_tick & to_key are partially opposite operations but this standardize on a single notation so that they can
+        # all target each other. eg, this removes spaces in "list strings", instead of hashing them directly
+        # XXX: but we might want to include that normalization feature in to_tick directly, instead of using to_key
+        #      explicitly here
+        # XXX: we might want to make hash use the position along the axis instead of the labels so that if an axis has
+        #      ambiguous labels, they do not hash to the same thing.
         # XXX: for performance reasons, I think hash should not evaluate slices. It should only translate pos bounds to
         #      labels or vice versa. We would loose equality between list Groups and equivalent slice groups but that
         #      is a small price to pay if the performance impact is large.
@@ -1196,8 +1328,7 @@ class LGroup(Group):
     Parameters
     ----------
     key : key
-        Anything usable for indexing.
-        A key should be either sequence of labels, a slice with label bounds or a string.
+        Anything usable for indexing. A key should be either sequence of labels, a slice with label bounds or a string.
     name : str, optional
         Name of the group.
     axis : int, str, Axis, optional
@@ -1205,14 +1336,14 @@ class LGroup(Group):
 
     Examples
     --------
-    >>> from larray import Axis, x
+    >>> from larray import Axis, X
     >>> age = Axis('0..100', 'age')
-    >>> teens = x.age[10:19].named('teens')
+    >>> teens = X.age[10:19].named('teens')
     >>> teens
-    x.age[10:19] >> 'teens'
-    >>> teens = x.age[10:19] >> 'teens'
+    X.age[10:19] >> 'teens'
+    >>> teens = X.age[10:19] >> 'teens'
     >>> teens
-    x.age[10:19] >> 'teens'
+    X.age[10:19] >> 'teens'
     """
     format_string = "{axis}[{key}]"
 
@@ -1220,7 +1351,7 @@ class LGroup(Group):
         key = _to_key(key)
         Group.__init__(self, key, name, axis)
 
-    #XXX: return PGroup instead?
+    # XXX: return IGroup instead?
     def translate(self, bound=None, stop=False):
         """
         compute position(s) of group
@@ -1257,8 +1388,7 @@ class LSet(LGroup):
     Parameters
     ----------
     key : key
-        Anything usable for indexing.
-        A key should be either sequence of labels, a slice with label bounds or a string.
+        Anything usable for indexing. A key should be either sequence of labels, a slice with label bounds or a string.
     name : str, optional
         Name of the set.
     axis : int, str, Axis, optional
@@ -1305,8 +1435,7 @@ class LSet(LGroup):
                 name = '%s %s %s' % (self.name, c, other.name)
             else:
                 name = None
-            # TODO: implement this in a more efficient way for ndarray keys
-            #       which can be large
+            # TODO: implement this in a more efficient way for ndarray keys which can be large
             result_set = getattr(self.key, op_fullname)(other.key)
             return LSet(result_set, name=name, axis=axis)
         opmethod.__name__ = op_fullname
@@ -1322,17 +1451,16 @@ class LSet(LGroup):
     __sub__ = difference
 
 
-class PGroup(Group):
-    """Positional Group.
+class IGroup(Group):
+    """Index Group.
 
     Represents a subset of indices of an axis.
 
     Parameters
     ----------
     key : key
-        Anything usable for indexing.
-        A key should be either a single position, a sequence of positions, or a slice with
-        integer bounds.
+        Anything usable for indexing. A key should be either a single position, a sequence of positions, or a slice
+        with integer bounds.
     name : str, optional
         Name of the group.
     axis : int, str, Axis, optional
@@ -1356,7 +1484,7 @@ class PGroup(Group):
             if isinstance(key, slice):
                 start = labels[key.start] if key.start is not None else None
                 # FIXME: this probably breaks for reverse slices
-                # - 1 because PGroup slice stop is excluded while LGroup slice stop is included
+                # - 1 because IGroup slice stop is excluded while LGroup slice stop is included
                 stop = labels[key.stop - 1] if key.stop is not None else None
                 return slice(start, stop, key.step)
             else:
@@ -1372,5 +1500,6 @@ class PGroup(Group):
             raise ValueError("Cannot evaluate a positional group without axis")
 
     def __hash__(self):
-        return hash(('PGroup', _to_tick(self.key)))
+        return hash(('IGroup', _to_tick(self.key)))
 
+PGroup = renamed_to(IGroup, 'PGroup')
